Struct loki_api::logproto::TimeSeriesChunk
source · pub struct TimeSeriesChunk {
pub from_ingester_id: String,
pub user_id: String,
pub labels: Vec<LabelPair>,
pub chunks: Vec<Chunk>,
}Fields
from_ingester_id: Stringuser_id: Stringlabels: Vec<LabelPair>chunks: Vec<Chunk>Trait Implementations
sourceimpl Clone for TimeSeriesChunk
impl Clone for TimeSeriesChunk
sourcefn clone(&self) -> TimeSeriesChunk
fn clone(&self) -> TimeSeriesChunk
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for TimeSeriesChunk
impl Debug for TimeSeriesChunk
sourceimpl Default for TimeSeriesChunk
impl Default for TimeSeriesChunk
sourceimpl Message for TimeSeriesChunk
impl Message for TimeSeriesChunk
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.sourceimpl PartialEq for TimeSeriesChunk
impl PartialEq for TimeSeriesChunk
sourcefn eq(&self, other: &TimeSeriesChunk) -> bool
fn eq(&self, other: &TimeSeriesChunk) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl StructuralPartialEq for TimeSeriesChunk